@@ -7,10 +7,14 @@ from openpyxl import load_workbook  # type: ignore
 
 from xlcsv import utils
 
+# default .xlsx sheet name
+DEFAULT_EXCEL_SHEET_NAME = "Sheet1"
+
 
 def excel_to_csv_buffer(
     file_like: Union[str, BytesIO, Path, BinaryIO, bytes],
-    sheet_name: Optional[str] = "Sheet1",
+    sheet_name: Optional[str] = None,
+    sheet_index: Optional[int] = None,
 ) -> StringIO:
     """Build a reset StringIO buffer of CSV data from Excel.
 
@@ -20,11 +24,14 @@ def excel_to_csv_buffer(
             ``read()`` method, such as a file handler
             (e.g. via builtin ``open`` function) or ``BytesIO``.
         sheet_name (Optional[str], optional): Name of sheet to read.
-            Defaults to "Sheet1".
+            Defaults to None.
+        sheet_index (Optional[int], optional): Position of sheet in book.
+            Defaults to None.
 
     Returns:
         StringIO: Reset String IO buffer.
     """
+
     if isinstance(file_like, (str, Path)):
         file_like = utils.format_path(file_like)
 
@@ -34,7 +41,7 @@ def excel_to_csv_buffer(
         read_only=True,
         data_only=True,
     )
-    sheet = book[sheet_name]
+    sheet = book[sheet_name or sheet_index or DEFAULT_EXCEL_SHEET_NAME]
 
     # write book to csv string io
     buffer = StringIO()
